==> java-sdk-1.0.0-20200703.162229-51-sources.jar: com/phonepe/sdk/javasdk/transaction/init/TransactionInitiatorFactory.java <==
package com.phonepe.sdk.javasdk.transaction.init;

import com.phonepe.sdk.javasdk.config.models.InitConfig;
import com.phonepe.sdk.javasdk.config.models.MerchantConfig;
import com.phonepe.sdk.javasdk.config.models.enums.InitType.InitTypeVisitor;
import com.phonepe.sdk.javasdk.transaction.checksum.payload.ChecksumPayload;
import com.phonepe.sdk.javasdk.transaction.client.TransactionClient;
import com.phonepe.sdk.javasdk.transaction.init.models.InitRequest;
import com.phonepe.sdk.javasdk.transaction.init.web.WebTransactionInitiator;
import com.phonepe.sdk.javasdk.transaction.request.PhonePeHttpRequestCreator;
import lombok.AllArgsConstructor;
import lombok.Builder;
import lombok.Data;
import lombok.NoArgsConstructor;

@Data
@NoArgsConstructor
@AllArgsConstructor
@Builder
public class TransactionInitiatorFactory implements InitTypeVisitor<TransactionInitiator> {

    private MerchantConfig merchantConfig;
    private InitConfig initConfig;
    private TransactionClient transactionClient;
    private ChecksumPayload checksumPayload;
    private PhonePeHttpRequestCreator<InitRequest> phonePeHttpRequestCreator;

    @Override
    public TransactionInitiator visitWeb() {
        return WebTransactionInitiator.builder()
                                      .phonePeHttpRequestCreator(this.phonePeHttpRequestCreator)
                                      .checksumPayload(this.checksumPayload)
                                      .transactionClient(this.transactionClient)
                                      .merchantConfig(this.merchantConfig)
                                      .initConfig(this.initConfig)
                                      .build();
    }

    @Override
    public TransactionInitiator visitIntent() {return null; }
}

==> java-sdk-1.0.0-20200723.085625-64-sources.jar: com/phonepe/sdk/javasdk/transaction/init/TransactionInitiatorFactory.java <==
package com.phonepe.sdk.javasdk.transaction.init;

import com.phonepe.sdk.javasdk.config.models.InitConfig;
import com.phonepe.sdk.javasdk.config.models.MerchantConfig;
import com.phonepe.sdk.javasdk.config.models.enums.InitType.InitTypeVisitor;
import com.phonepe.sdk.javasdk.transaction.checksum.payload.ChecksumGenerator;
import com.phonepe.sdk.javasdk.transaction.client.TransactionClient;
import com.phonepe.sdk.javasdk.transaction.init.models.InitRequest;
import com.phonepe.sdk.javasdk.transaction.init.web.WebTransactionInitiator;
import com.phonepe.sdk.javasdk.transaction.request.PhonePeHttpRequestCreator;
import lombok.AllArgsConstructor;
import lombok.Builder;
import lombok.Data;
import lombok.NoArgsConstructor;

@Data
@NoArgsConstructor
@AllArgsConstructor
@Builder
public class TransactionInitiatorFactory implements InitTypeVisitor<TransactionInitiator> {

    private MerchantConfig merchantConfig;
    private InitConfig initConfig;
    private TransactionClient transactionClient;
    private ChecksumGenerator checksumGenerator;
    private PhonePeHttpRequestCreator<InitRequest> phonePeHttpRequestCreator;

    @Override
    public TransactionInitiator visitWeb() {
        return WebTransactionInitiator.builder()
                                      .phonePeHttpRequestCreator(this.phonePeHttpRequestCreator)
                                      .checksumGenerator(this.checksumGenerator)
                                      .transactionClient(this.transactionClient)
                                      .merchantConfig(this.merchantConfig)
                                      .initConfig(this.initConfig)
                                      .build();
    }

    @Override
    public TransactionInitiator visitIntent() {return null; }
}
